"""ext control plane

Revision ID: d9b711555be8
Revises: 7868bcd05006
Create Date: 2025-09-10 09:05:05.736095

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = 'd9b711555be8'
down_revision: Union[str, Sequence[str], None] = '7868bcd05006'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('k8s_ext_control_plan',
    sa.Column('stack_fqdn', sa.String(length=253), nullable=False),
    sa.Column('zone', sa.String(length=253), nullable=True),
    sa.Column('name', sa.String(length=253), nullable=True),
    sa.PrimaryKeyConstraint('stack_fqdn')
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('k8s_ext_control_plan')
    # ### end Alembic commands ###
